@@ -22,8 +22,6 @@
 #include <QGridLayout>
 #include <QVBoxLayout>
 
-class QGridLayout;
-class QVBoxLayout;
 
 
 class KGame;
@@ -90,7 +88,7 @@ public:
 	KGameDialog(KGame* g, KPlayer* owner, const QString& title, 
 			QWidget* parent);
 
-	virtual ~KGameDialog();
+	~KGameDialog() override;
 
 
 	/**
